pub struct ServerCertVerifier { /* private fields */ }Expand description
Server certificate verifier.
Implementations
Sourceimpl ServerCertVerifier
impl ServerCertVerifier
Sourcepub fn new(
roots: &RootCertStore,
) -> Result<ServerCertVerifier, ServerCertVerifierError>
pub fn new( roots: &RootCertStore, ) -> Result<ServerCertVerifier, ServerCertVerifierError>
Creates a new server certificate verifier.
Sourcepub fn mozilla() -> ServerCertVerifier
pub fn mozilla() -> ServerCertVerifier
Creates a server certificate verifier with Mozilla root certificates.
These certificates are sourced from webpki-root-certs. It is not recommended to use these unless the
application binary can be recompiled and deployed on-demand in the case
that the root certificates need to be updated.
Sourcepub fn verify_server_cert(
&self,
end_entity: &CertificateDer,
intermediates: &[CertificateDer],
server_name: &ServerName,
time: u64,
) -> Result<(), ServerCertVerifierError>
pub fn verify_server_cert( &self, end_entity: &CertificateDer, intermediates: &[CertificateDer], server_name: &ServerName, time: u64, ) -> Result<(), ServerCertVerifierError>
Verifies the server certificate was valid at the given time of presentation.
Arguments
end_entity- End-entity certificate to verify.intermediates- Intermediate certificates to a trust anchor.server_name- Server DNS name.time- Unix time the certificate was presented.